/*

interstellar-helper.js

Script for the ship that asks for your help in interstellar space.


Oolite
Copyright © 2004-2011 Giles C Williams and contributors

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
MA 02110-1301, USA.


interstellar_help.oxp
Copyright © 2008-2011 "Commander McLane"

This work is licensed under the Creative Commons
Attribution-Noncommercial-Share Alike 3.0 Unported License.

To view a copy of this license, visit
http://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter
to Creative Commons, 171 Second Street, Suite 300, San Francisco,
California, 94105, USA.

*/

"use strict";
this.name           = "interstellar-helper";
this.author         = "Commander McLane";
this.copyright      = "© 2011 Commander McLane";
this.license		= "CC-by-nc-sa 3.0";
this.version        = "2.1";


this.$playerInScannerRange = function()
{
	if(this.ship.position.distanceTo(player.ship) < 24000)
	{
		this.ship.reactToAIMessage("APPROACHING_PLAYER");
	}
}

this.$checkPlayerApproached = function()
{
	if(this.ship.position.distanceTo(player.ship) < 7000)
	{
		this.ship.reactToAIMessage("PLAYER_APPROACHED");
	}
}

this.$checkForFuelScoops = function()
{
	if(player.ship.equipmentStatus("EQ_FUEL_SCOOPS") != "EQUIPMENT_OK")
	{
		this.ship.AIState = "WORMHOLE";
	}
}

this.$startWaiting = function()
{
    this.waitTimer = new Timer(this, this.$stopWaiting, 30);
}

this.$stopWaiting = function()
{
    this.ship.commsMessage("Sorry commander, I ain't got time forever. Have to continue my journey. So long!");
    this.ship.AIState = "GOOD_BYE";
    this.ship.primaryRole = "trader";
    delete this.waitTimer;
}

this.$checkDistanceToPlayer = function()
{
	if(this.ship.position.distanceTo(player.ship) < 250 && player.ship.heading.angleTo(this.ship.position.subtract(player.ship.position).direction()) < 0.15)
	{
		this.waitTimer.stop();
        delete this.waitTimer;
		this.ship.AIState = "REFUELING";
		this.fuelTransferred = 0;
		this.payment = 0;
		if(!this.refuelTimer)
			this.refuelTimer = new Timer(this, this.$refuelPlayerShip, 1, 1);
		else
			this.refuelTimer.start();
	}
}

this.$refuelPlayerShip = function()
{
	if(player.ship.heading.angleTo(this.ship.position.subtract(player.ship.position).direction()) < 0.15)
	{
		player.ship.fuel += 0.2;
		this.ship.fuel -= 0.2;
		player.credits -= 4;
		this.fuelTransferred += 0.2;
		this.payment += 4;
		player.consoleMessage("Fuel transferred: " + Math.round(this.fuelTransferred * 10) / 10 + " LY. Price: " + this.payment + expandDescription("[interstellar_help_cr]"), 1);
		if(this.ship.fuel < 3.4)
		{
			this.refuelTimer.stop();
			this.ship.reactToAIMessage("NO_MORE_FUEL");
            this.ship.primaryRole = "trader";
		}
		if(player.ship.fuel >= 7)
		{
			this.refuelTimer.stop();
			this.ship.reactToAIMessage("FULL");
            this.ship.primaryRole = "trader";
		}
		if(player.credits < 4)
		{
			this.refuelTimer.stop();
			this.ship.reactToAIMessage("NO_MORE_MONEY");
            this.ship.primaryRole = "trader";
		}
	}
	else
	{
		this.refuelTimer.stop();
		this.ship.reactToAIMessage("TRANSACTION_COMPLETE");
            this.ship.primaryRole = "trader";
	}
}

this.shipSpawned = this.$setTargetToPlayer = function()
{
	this.ship.target = player.ship;
}

this.shipDied = function()
{
	this.ship.fuel = 0;
}
